Based on the supplied within-subjects factors and between-subjects factors, this function
constructs all conditions of the ANOVA design and opens two dialog windows querying for
the expected correlation matrix and cell means (+ standard deviations) for all conditions.
The first dialog window queries for the correlation matrix of the conditions. If you have
a pure between-subjects design, you may instantly close this window. Otherwise, enter the
expected correlations between all conditions that include within-subjects manipulations.
Using the "default_within_correlation" parameter, a default value can be set. You should
fill in only the lower triangle of the correlation matrix and only the values not containing
NAs.
The second dialog window queries for the means and standard deviations expected for each
condition.
Use the "save_input_as" parameter in order to define a file name prefix of the files where
the function saves your input values. This will populate the dialog windows with the saved
values on the next execution of this function. If the parameter is NULL, input values will
not be saved. NOTE: You must delete the respective files if you want to change the design.